/*
 * Copyright (c) 2008, 2016, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

namespace wb {
  class ModelDiagramForm;
  class WBContextModel;
};

namespace mforms {
  class View;
};

@class MCanvasViewer;
@class GRTTreeDataSource;
@class GRTListDataSource;


@interface WBModelSidebarController : NSObject
{
  IBOutlet __weak NSTabViewItem *historyTab;
  IBOutlet __weak NSTabViewItem *userTypesTab;
  IBOutlet __weak NSTabViewItem *catalogTreeTab;

  IBOutlet __weak NSTableView *propertiesTable;

  mforms::View *_udtlist;
  mforms::View *_history;
  mforms::View *_catalog_tree;
}

- (void)setupWithContext:(wb::WBContextModel*)context;
- (void)setupWithDiagramForm:(wb::ModelDiagramForm*)form;
- (void)invalidate;

@end
